@@ -28,27 +28,27 @@ brain.add_morphometry("curv", colormap="binary",
 The easiest way to label any vertex that could be in the region is with
 add_label.
 """
-brain.add_label("BA1_exvivo", color="#A6BDDB")
+brain.add_label("BA1", color="#A6BDDB")
 
 """
 You can also threshold based on the probability of that region being at each
 vertex.
 """
-brain.add_label("BA1_exvivo", color="#2B8CBE", scalar_thresh=.5)
+brain.add_label("BA1", color="#2B8CBE", scalar_thresh=.5)
 
 """
 It's also possible to plot just the label boundary, in case you wanted to
 overlay the label on an activation plot to asses whether it falls within that
 region.
 """
-brain.add_label("BA45_exvivo", color="#F0F8FF", borders=3, scalar_thresh=.5)
-brain.add_label("BA45_exvivo", color="#F0F8FF", alpha=.3, scalar_thresh=.5)
+brain.add_label("BA45", color="#F0F8FF", borders=3, scalar_thresh=.5)
+brain.add_label("BA45", color="#F0F8FF", alpha=.3, scalar_thresh=.5)
 
 """
 Finally, with a few tricks, you can display the whole probabilistic map.
 """
 subjects_dir = environ["SUBJECTS_DIR"]
-label_file = join(subjects_dir, "fsaverage", "label", "lh.BA6_exvivo.label")
+label_file = join(subjects_dir, "fsaverage", "label", "lh.BA6.label")
 
 prob_field = np.zeros_like(brain.geo['lh'].x)
 ids, probs = read_label(label_file, read_scalars=True)
