@@ -10,7 +10,7 @@ the data.
 
 """
 import os
-from surfer import Brain, io
+from surfer import Brain, project_volume_data
 
 print(__doc__)
 
@@ -22,8 +22,8 @@ brain = Brain("fsaverage", "split", "inflated",
 mri_file = "example_data/resting_corr.nii.gz"
 reg_file = os.path.join(os.environ["FREESURFER_HOME"],
                         "average/mni152.register.dat")
-surf_data_lh = io.project_volume_data(mri_file, "lh", reg_file)
-surf_data_rh = io.project_volume_data(mri_file, "rh", reg_file)
+surf_data_lh = project_volume_data(mri_file, "lh", reg_file)
+surf_data_rh = project_volume_data(mri_file, "rh", reg_file)
 
 """
 You can pass this array to the add_overlay method for a typical activation
@@ -45,15 +45,27 @@ for overlay in brain.overlays_dict["ang_corr_rh"]:
 """
 We want to use an appropriate color map for these data: a divergent map that
 is centered on 0, which is a meaningful transition-point as it marks the change
-from negative correlations to positive correlations.
-
-We'll also plot the map with some transparency so that we can see through to
-the underlying anatomy.
+from negative correlations to positive correlations. By providing the 'center'
+argument the add_data function automatically chooses a divergent colormap.
 """
-brain.add_data(surf_data_lh, -.7, .7, colormap="coolwarm", alpha=.75,
-               hemi='lh')
-brain.add_data(surf_data_rh, -.7, .7, colormap="coolwarm", alpha=.75,
-               hemi='rh')
+brain.add_data(surf_data_lh, 0, .7, center=0, hemi='lh')
+brain.add_data(surf_data_rh, 0, .7, center=0, hemi='rh')
+
+"""
+You can tune the data display by shifting the colormap around interesting
+regions. For example, you can ignore small correlation up to a magnitude of 0.2
+and let colors become gradually less transparent from 0.2 to 0.5 by re-scaling
+the colormap as follows. For more information see the help string of this
+function.
+"""
+brain.scale_data_colormap(.2, .5, .7, transparent=True, center=0)
+
+"""
+You can also set the overall opacity of the displayed data while maintaining
+the transparency of the small values.
+"""
+brain.scale_data_colormap(0, .35, .7, transparent=True, center=0,
+                          alpha=0.75)
 
 """
 This overlay represents resting-state correlations with a
